Learn R Programming

GB2 (version 1.0)

Contprof: Contour Plot of the Profile Log-likelihood of the GB2 Distribution

Description

Produces a contour plot of the profile log-likelihood, which is a function of two parameters only.

Usage

contprof.gb2(z, w=1, resol, low=0.1, high=20)

Arguments

z
a numeric vector; in general, the income values.
w
a numeric vector of the same length as z; the sampling weights. If not available, the function should be called only with its first argument (the weights are set to 1).
resol
a scalar; number of grid points horizontally and vertically. For better graph quality, we recommend a value of 100.
low, high
scalar; lower and upper factors for scale.

Value

  • A contour plot of the profile log-likelihood. The initial Fisk estimate is added as point "F".

Details

The matrix containing the values to be plotted (NAs are allowed) is of size resol $\times$ resol. The locations of the grid lines at which the values of the profile log-likelihood are measured are equally-spaced values between low and high multiplied by the initial parameters.

See Also

fisk for the Fisk estimate, ProfLogLikelihood for the profile log-likelihood and contour (package graphics) for more details on contour plots.