Learn R Programming

GB2 (version 1.0)

LogDensity: Log Density of the GB2 Distribution

Description

Calculates the log density of the GB2 distribution for a single value or a vector of values. Calculates the first- and second-order partial derivatives of the log density evaluated at a single value.

Usage

logf.gb2(x, shape1, scale, shape2, shape3)
dlogf.gb2(xi, shape1, scale, shape2, shape3)
d2logf.gb2(xi, shape1, scale, shape2, shape3)

Arguments

xi
a scalar.
x
a scalar or a numeric vector.
shape1
positive parameter.
scale
positive parameter.
shape2, shape3
positive parameters of the Beta distribution.

Value

  • Depending on the input logf.gb2 gives the log density for a single value or a vector of values. dlogf.gb2 gives the vector of the four first-order partial derivatives of the log density and d2logf.gb2 gives the $4 \times 4$ matrix of second-order partial derivatives of the log density.

Details

We calculate $log(f(x, \theta))$, where $f$ is the GB2 density with parameters shape1 $= a$, scale $= b$, shape2 $= p$ and shape3 $= q$, $\theta$ is the parameter vector. We calculate the first- and second-order partial derivatives of $log(f(x, \theta))$ with respect to the parameter vector $\theta$.

References

Brazauskas, V. (2002) Fisher information matrix for the Feller-Pareto distribution. Statistics & Probability Letters, 59, 159--167.