Learn R Programming

GB2 (version 1.0)

ProfLogLikelihood: Profile Log-likelihood of the GB2 Distribution

Description

Estimation of the parameters shape2 $=p$ and shape3 $=q$ of the GB2 distribution as functions of shape1 $=a$ and scale $=b$, profile log-likelihood of the GB2 distribution, scores of the profile log-likelihood.

Usage

prof.gb2(x, shape1, scale, w=1)
proflogl.gb2(x, shape1, scale, w=1)
profscores.gb2(x, shape1, scale, w=1)

Arguments

x
vector of data values.
shape1
positive parameter.
scale
positive parameter.
w
vector of weights.

Value

  • prof returns a vector containing the estimates of $r$, $s$, $p$, $q$ as well as two other parameters used in the calculation of the profile log-likelihood and the scores. proflogl.gb2 returns the value of the profile log-likelihood and profscores.gb2 returns the vector of the first derivatives of the profile log-likelihhod with respect to $a$ and $b$.

Details

Using the full log-likelihood equations for the GB2 distribution, the parameters $p$ and $q$ can be estimated as functions of $a$ and $b$. These functions are plugged into the log-likelihood expression, which becomes a function of $a$ and $b$ only. This is obtained by reparametrizing the GB2, i.e. we set $r=\frac{p}{p+q}$ and $s=p+q$. More details can be found in Graf (2009).

References

Graf, M. (2009) The Log-Likelihood of the Generalized Beta Distribution of the Second Kind. working paper, SFSO.