Usage
ULg(U, L)
combiopt(g)
Thomae(U, L, lB, tol, maxiter, debug)
gb2.gini(shape1, shape2, shape3, tol=1e-08, maxiter=10000, debug=FALSE)
Arguments
U
vector of length 3 giving the upper arguments of the generalized hypergeometric function $_{3}F_{2}$.
L
vector of length 2 giving the lower arguments of the generalized hypergeometric function $_{3}F_{2}$.
g
vector of Thomae's permuting arguments.
lB
ratio of beta functions (a common factor in the expression of the Gini coefficient under the GB2).
shape1
positive parameter.
shape2, shape3
positive parameters of the Beta distribution.
tol
tolerance with default 0, meaning to iterate until additional terms do not change the partial sum.
maxiter
maximum number of iterations to perform.
debug
boolean; if TRUE, returns the list of changes to the partial sum.