contprof.gb2(z, w=1, resol, low=0.1, high=20)z; the sampling weights. If not available, the function should be called only with its first argument (the weights are set to 1).resol $\times$ resol.
The locations of the grid lines at which the values of the profile log-likelihood are measured are equally-spaced values between low and high
multiplied by the initial parameters.fisk for the Fisk estimate, ProfLogLikelihood for the profile log-likelihood and contour (package graphics) for more details on contour plots.