plotsML.gb2 produces two plots. The first is a plot of the empirical cumulative distribution function versus the fitted cumulative distibution function.
The second is a plot of the kernel density versus the fitted GB2 density. Function saveplot saves locally the produced plot.plotsML.gb2(z, shape1, scale, shape2, shape3, w=1)
saveplot(name, pathout)z; the sampling weights. If not available, the function should be called only with its first argument (the weights are set to 1).plot.density).