shape2 $=p$ and shape3 $=q$ of the GB2 distribution as functions of shape1 $=a$ and scale $=b$,
profile log-likelihood of the GB2 distribution, scores of the profile log-likelihood.prof.gb2(x, shape1, scale, w=1)
proflogl.gb2(x, shape1, scale, w=1)
profscores.gb2(x, shape1, scale, w=1)prof returns a vector containing the estimates of $r$, $s$, $p$, $q$ as well as two other parameters used in the calculation of the profile log-likelihood and the scores.
proflogl.gb2 returns the value of the profile log-likelihood and profscores.gb2 returns the vector of the first derivatives of the profile log-likelihhod with respect to $a$ and $b$.